"""Configuration module for Phone Agent."""

from AutoGLM_GUI.phone_agent.config.apps import APP_PACKAGES
from AutoGLM_GUI.phone_agent.config.prompts import SYSTEM_PROMPT

__all__ = ["APP_PACKAGES", "SYSTEM_PROMPT"]
